@@ -147,6 +147,7 @@ class Node:
             try:
                 resp = requests.post(f'http://{target}/ping/', json={
                     'node_name': self.name,
+                    'node_network': self.network,
                     'known_servers': list(self.server_info.keys())
                 })
                 dat = resp.json()
@@ -254,6 +255,8 @@ class Node:
                 'Must enable either local or remote connections, or both.')
 
         self.max_remotes = max_remotes
+        if self.max_remotes == None:
+            self.max_remotes = 1e99
         self.local_server = None
         self.running = False
         self.advertising_socket = socket(AF_INET, SOCK_DGRAM)
@@ -383,8 +386,9 @@ class Node:
                     else:
                         raise requests.ConnectionError
                 except (requests.ConnectionError, requests.Timeout):
-                    del self.remote_peers[i]
+                    self.remote_peers[i].remove(remote_target)
             if ret == None:
+                del self.remote_peers[i]
                 if raise_errors:
                     raise TimeoutError(
                         f'Attempt to reach peer {i} remotely failed.')
